@@ -31,6 +31,8 @@ modules = [
     "erome",
     "exhentai",
     "fallenangels",
+    "fanbox",
+    "fantia",
     "flickr",
     "furaffinity",
     "fuskator",
@@ -40,6 +42,7 @@ modules = [
     "gfycat",
     "hbrowse",
     "hentai2read",
+    "hentaicosplays",
     "hentaifoundry",
     "hentaifox",
     "hentaihand",
@@ -127,7 +130,6 @@ modules = [
     "wikiart",
     "xhamster",
     "xvideos",
-    "yuki",
     "booru",
     "moebooru",
     "foolfuuka",
