@@ -259,9 +259,10 @@ class DeviantartExtractor(Extractor):
 
     @staticmethod
     def _find_folder(folders, name):
-        pattern = re.compile(r"(?i)\W*" + name.replace("-", r"\W+") + r"\W*$")
+        match = re.compile(name.replace(
+            "-", r"[^a-z0-9]+") + "$", re.IGNORECASE).match
         for folder in folders:
-            if pattern.match(folder["name"]):
+            if match(folder["name"]):
                 return folder
         raise exception.NotFoundError("folder")
 
@@ -472,6 +473,12 @@ class DeviantartFolderExtractor(DeviantartExtractor):
             "count": ">= 4",
             "options": (("original", False),),
         }),
+        # name starts with '_', special characters (#1451)
+        (("https://www.deviantart.com/justatest235723"
+          "/gallery/69302698/-test-b-c-d-e-f-"), {
+            "count": 1,
+            "options": (("original", False),),
+        }),
         ("https://shimoda7.deviantart.com/gallery/722019/Miscellaneous"),
         ("https://yakuzafc.deviantart.com/gallery/37412168/Crafts"),
     )
@@ -911,7 +918,7 @@ class DeviantartOAuthAPI():
     def __init__(self, extractor):
         self.extractor = extractor
         self.log = extractor.log
-        self.headers = {}
+        self.headers = {"dA-minor-version": "20200519"}
 
         self.delay = extractor.config("wait-min", 0)
         self.delay_min = max(2, self.delay)
@@ -923,10 +930,12 @@ class DeviantartOAuthAPI():
         self.folders = extractor.config("folders", False)
         self.metadata = extractor.extra or extractor.config("metadata", False)
 
-        self.client_id = extractor.config(
-            "client-id", self.CLIENT_ID)
-        self.client_secret = extractor.config(
-            "client-secret", self.CLIENT_SECRET)
+        self.client_id = extractor.config("client-id")
+        if self.client_id:
+            self.client_secret = extractor.config("client-secret")
+        else:
+            self.client_id = self.CLIENT_ID
+            self.client_secret = self.CLIENT_SECRET
 
         token = extractor.config("refresh-token")
         if token is None or token == "cache":
@@ -1230,7 +1239,7 @@ class DeviantartEclipseAPI():
         params = {
             "username"     : user,
             "offset"       : offset,
-            "limit"        : "24",
+            "limit"        : 24,
             "scraps_folder": "true",
         }
         return self._pagination(endpoint, params)
@@ -1240,8 +1249,8 @@ class DeviantartEclipseAPI():
         params = {
             "username": user,
             "moduleid": self._module_id_watching(user),
-            "offset"  : None,
-            "limit"   : "24",
+            "offset"  : offset,
+            "limit"   : 24,
         }
         return self._pagination(endpoint, params)
 
@@ -1260,14 +1269,23 @@ class DeviantartEclipseAPI():
         except Exception:
             return {"error": response.text}
 
-    def _pagination(self, endpoint, params=None):
+    def _pagination(self, endpoint, params):
         while True:
             data = self._call(endpoint, params)
-            yield from data["results"]
 
-            if not data["hasMore"]:
+            results = data.get("results")
+            if results is None:
                 return
-            params["offset"] = data["nextOffset"]
+            yield from results
+
+            if not data.get("hasMore"):
+                return
+
+            next_offset = data.get("nextOffset")
+            if next_offset:
+                params["offset"] = next_offset
+            else:
+                params["offset"] += params["limit"]
 
     def _module_id_watching(self, user):
         url = "{}/{}/about".format(self.extractor.root, user)
