@@ -8,8 +8,10 @@
 
 """Extractors for https://gelbooru.com/"""
 
+from .common import Extractor, Message
 from . import gelbooru_v02
 from .. import text, exception
+import binascii
 
 
 class GelbooruBase():
@@ -91,10 +93,63 @@ class GelbooruPostExtractor(GelbooruBase,
             "content": "5e255713cbf0a8e0801dc423563c34d896bb9229",
             "count": 1,
         }),
+        ("https://gelbooru.com/index.php?page=post&s=view&id=6018318", {
+            "options": (("tags", True),),
+            "content": "977caf22f27c72a5d07ea4d4d9719acdab810991",
+            "keyword": {
+                "tags_artist": "kirisaki_shuusei",
+                "tags_character": str,
+                "tags_copyright": "vocaloid",
+                "tags_general": str,
+                "tags_metadata": str,
+            },
+        }),
         # video
         ("https://gelbooru.com/index.php?page=post&s=view&id=5938076", {
             "content": "6360452fa8c2f0c1137749e81471238564df832a",
             "pattern": r"https://img\d\.gelbooru\.com/images"
                        r"/22/61/226111273615049235b001b381707bd0\.webm",
         }),
+        # notes
+        ("https://gelbooru.com/index.php?page=post&s=view&id=5997331", {
+            "options": (("notes", True),),
+            "keywords": {
+                "notes": [
+                    {
+                        "height": 553,
+                        "body": "Look over this way when you talk~",
+                        "width": 246,
+                        "x": 35,
+                        "y": 72
+                    },
+                    {
+                        "height": 557,
+                        "body": "Hey~\nAre you listening~?",
+                        "width": 246,
+                        "x": 1233,
+                        "y": 109
+                    }
+                ]
+            }
+        }),
     )
+
+
+class GelbooruRedirectExtractor(GelbooruBase, Extractor):
+    subcategory = "redirect"
+    pattern = (r"(?:https?://)?(?:www\.)?gelbooru\.com"
+               r"/redirect\.php\?s=([^&#]+)")
+    test = (("https://gelbooru.com/redirect.php?s=Ly9nZWxib29ydS5jb20vaW5kZXgu"
+             "cGhwP3BhZ2U9cG9zdCZzPXZpZXcmaWQ9MTgzMDA0Ng=="), {
+        "pattern": r"https://gelbooru.com/index.php"
+                   r"\?page=post&s=view&id=1830046"
+    })
+
+    def __init__(self, match):
+        Extractor.__init__(self, match)
+        self.redirect_url = text.ensure_http_scheme(
+            binascii.a2b_base64(match.group(1)).decode())
+
+    def items(self):
+        data = {"_extractor": GelbooruPostExtractor}
+        yield Message.Queue, self.redirect_url, data
