@@ -100,6 +100,10 @@ class NijieExtractor(AsynchronousMixin, Extractor):
 
     @cache(maxage=150*24*3600, keyarg=1)
     def _login_impl(self, username, password):
+        if not username or not password:
+            raise exception.AuthenticationError(
+                "Username and password required")
+
         self.log.info("Logging in as %s", username)
         url = "{}/login_int.php".format(self.root)
         data = {"email": username, "password": password, "save": "on"}
