@@ -32,10 +32,11 @@ class TwitterExtractor(Extractor):
     def __init__(self, match):
         Extractor.__init__(self, match)
         self.user = match.group(1)
-        self.retweets = self.config("retweets", True)
+        self.textonly = self.config("text-tweets", False)
+        self.retweets = self.config("retweets", False)
         self.replies = self.config("replies", True)
         self.twitpic = self.config("twitpic", False)
-        self.quoted = self.config("quoted", True)
+        self.quoted = self.config("quoted", False)
         self.videos = self.config("videos", True)
         self.cards = self.config("cards", False)
         self._user_cache = {}
@@ -43,7 +44,6 @@ class TwitterExtractor(Extractor):
     def items(self):
         self.login()
         metadata = self.metadata()
-        yield Message.Version, 1
 
         for tweet in self.tweets():
 
@@ -64,7 +64,7 @@ class TwitterExtractor(Extractor):
                 self._extract_card(tweet, files)
             if self.twitpic:
                 self._extract_twitpic(tweet, files)
-            if not files:
+            if not files and not self.textonly:
                 continue
 
             tdata = self._transform_tweet(tweet)
@@ -168,7 +168,6 @@ class TwitterExtractor(Extractor):
                 tweet["created_at"], "%a %b %d %H:%M:%S %z %Y"),
             "user"          : self._transform_user(tweet["user"]),
             "lang"          : tweet["lang"],
-            "content"       : tweet["full_text"],
             "favorite_count": tweet["favorite_count"],
             "quote_count"   : tweet["quote_count"],
             "reply_count"   : tweet["reply_count"],
@@ -187,6 +186,14 @@ class TwitterExtractor(Extractor):
                 "nick": u["name"],
             } for u in mentions]
 
+        content = tweet["full_text"]
+        urls = entities.get("urls")
+        if urls:
+            for url in urls:
+                content = content.replace(url["url"], url["expanded_url"])
+        txt, _, tco = content.rpartition(" ")
+        tdata["content"] = txt if tco.startswith("https://t.co/") else content
+
         if "in_reply_to_screen_name" in tweet:
             tdata["reply_to"] = tweet["in_reply_to_screen_name"]
 
@@ -398,7 +405,6 @@ class TwitterFollowingExtractor(TwitterExtractor):
 class TwitterSearchExtractor(TwitterExtractor):
     """Extractor for all images from a search timeline"""
     subcategory = "search"
-    directory_fmt = ("{category}", "Search", "{search}")
     pattern = BASE_PATTERN + r"/search/?\?(?:[^&#]+&)*q=([^&#]+)"
     test = ("https://twitter.com/search?q=nature", {
         "range": "1-40",
@@ -448,14 +454,14 @@ class TwitterTweetExtractor(TwitterExtractor):
             "options": (("replies", False),),
             "count": 0,
         }),
-        # quoted tweet (#526, #854)
+        # "quoted" option (#854)
         ("https://twitter.com/StobiesGalaxy/status/1270755918330896395", {
+            "options": (("quoted", True),),
             "pattern": r"https://pbs\.twimg\.com/media/Ea[KG].+=jpg",
             "count": 8,
         }),
-        # "quoted" option (#854)
+        # quoted tweet (#526, #854)
         ("https://twitter.com/StobiesGalaxy/status/1270755918330896395", {
-            "options": (("quoted", False),),
             "pattern": r"https://pbs\.twimg\.com/media/EaK.+=jpg",
             "count": 4,
         }),
@@ -489,6 +495,11 @@ class TwitterTweetExtractor(TwitterExtractor):
             "options": (("conversations", True),),
             "count": ">= 50",
         }),
+        # retweet with missing media entities (#1555)
+        ("https://twitter.com/morino_ya/status/1392763691599237121", {
+            "options": (("retweets", True),),
+            "count": 4,
+        }),
     )
 
     def __init__(self, match):
@@ -802,6 +813,10 @@ class TwitterAPI():
                         tweet = retweet
                     elif retweet:
                         tweet["author"] = users[retweet["user_id_str"]]
+                        if "extended_entities" in retweet and \
+                                "extended_entities" not in tweet:
+                            tweet["extended_entities"] = \
+                                retweet["extended_entities"]
                 tweet["user"] = users[tweet["user_id_str"]]
                 yield tweet
 
